ChangeSet 1.2223.2.9, 2004/11/29 15:07:15-08:00, aris@cathedrallabs.org

[PATCH] i2c-ite: get rid of cli()/sti()

I found only this one. Next time I'll try to make better grep
expressions :^)

[I2C] i2c-ite: get rid of cli()/sti()

Signed-off-by: Aristeu Sergio Rozanski Filho <aris@cathedrallabs.org>
Signed-off-by: Greg Kroah-Hartman <greg@kroah.com>


 drivers/i2c/busses/i2c-ite.c |   31 +++++++++++++++++++++++--------
 1 files changed, 23 insertions(+), 8 deletions(-)


diff -Nru a/drivers/i2c/busses/i2c-ite.c b/drivers/i2c/busses/i2c-ite.c
--- a/drivers/i2c/busses/i2c-ite.c	2004-11-30 16:00:43 -08:00
+++ b/drivers/i2c/busses/i2c-ite.c	2004-11-30 16:00:43 -08:00
@@ -62,6 +62,7 @@
 static struct iic_ite gpi;
 static wait_queue_head_t iic_wait;
 static int iic_pending;
+static spinlock_t lock;
 
 /* ----- local functions ----------------------------------------------	*/
 
@@ -108,6 +109,7 @@
 static void iic_ite_waitforpin(void) {
 
    int timeout = 2;
+   long flags;
 
    /* If interrupts are enabled (which they are), then put the process to
     * sleep.  This process will be awakened by two events -- either the
@@ -116,24 +118,36 @@
     * of time and return.
     */
    if (gpi.iic_irq > 0) {
-	cli();
+	spin_lock_irqsave(&lock, flags);
 	if (iic_pending == 0) {
-		interruptible_sleep_on_timeout(&iic_wait, timeout*HZ );
-	} else
+		spin_unlock_irqrestore(&lock, flags);
+		if (interruptible_sleep_on_timeout(&iic_wait, timeout*HZ)) {
+			spin_lock_irqsave(&lock, flags);
+			if (iic_pending == 1) {
+				iic_pending = 0;
+			}
+			spin_unlock_irqrestore(&lock, flags);
+		}
+	} else {
 		iic_pending = 0;
-	sti();
+		spin_unlock_irqrestore(&lock, flags);
+	}
    } else {
       udelay(100);
    }
 }
 
 
-static void iic_ite_handler(int this_irq, void *dev_id, struct pt_regs *regs) 
+static irqreturn_t iic_ite_handler(int this_irq, void *dev_id,
+							struct pt_regs *regs)
 {
-	
-   iic_pending = 1;
+	spin_lock(&lock);
+	iic_pending = 1;
+	spin_unlock(&lock);
+
+	wake_up_interruptible(&iic_wait);
 
-   wake_up_interruptible(&iic_wait);
+	return IRQ_HANDLED;
 }
 
 
@@ -221,6 +235,7 @@
 
 	iic_ite_data.data = (void *)piic;
 	init_waitqueue_head(&iic_wait);
+	spin_lock_init(&lock);
 	if (iic_hw_resrc_init() == 0) {
 		if (i2c_iic_add_bus(&iic_ite_ops) < 0)
 			return -ENODEV;
